@@ -187,7 +187,7 @@ func TestConvertFrom(t *testing.T) {
 							Url: "ExternalPluginRegistries_2",
 						},
 					},
-					OpenVSXURL: "open-vsx-registry",
+					OpenVSXURL: pointer.StringPtr("open-vsx-registry"),
 				},
 				DevfileRegistry: chev2.DevfileRegistry{
 					Deployment: &chev2.Deployment{
@@ -302,19 +302,6 @@ func TestConvertFrom(t *testing.T) {
 					},
 				},
 				DevWorkspace: chev2.DevWorkspace{
-					Deployment: &chev2.Deployment{
-						Containers: []chev2.Container{
-							{
-								Image: "DevWorkspaceImage",
-								Env: []corev1.EnvVar{
-									{
-										Name:  "dev-workspace-name",
-										Value: "dev-workspace-value",
-									},
-								},
-							},
-						},
-					},
 					RunningLimit: "RunningLimit",
 				},
 			},
@@ -376,7 +363,8 @@ func TestConvertFrom(t *testing.T) {
 			},
 			DevEnvironments: chev2.CheClusterDevEnvironments{
 				DefaultNamespace: chev2.DefaultNamespace{
-					Template: "WorkspaceNamespaceName",
+					Template:      "WorkspaceNamespaceName",
+					AutoProvision: pointer.BoolPtr(true),
 				},
 				TrustedCerts: &chev2.TrustedCerts{
 					GitTrustedCertsConfigMapName: "che-git-self-signed-cert",
@@ -418,6 +406,26 @@ func TestConvertFrom(t *testing.T) {
 				Hostname:     "AirGapContainerRegistryHostname",
 				Organization: "AirGapContainerRegistryOrganization",
 			},
+			GitServices: chev2.CheClusterGitServices{
+				GitHub: []chev2.GitHubService{
+					{
+						SecretName: "github-secret-name",
+						Endpoint:   "github-endpoint",
+					},
+				},
+				GitLab: []chev2.GitLabService{
+					{
+						SecretName: "gitlab-secret-name",
+						Endpoint:   "gitlab-endpoint",
+					},
+				},
+				BitBucket: []chev2.BitBucketService{
+					{
+						SecretName: "bitbucket-secret-name",
+						Endpoint:   "bitbucket-endpoint",
+					},
+				},
+			},
 		},
 		Status: chev2.CheClusterStatus{
 			CheVersion:         "CheVersion",
@@ -479,13 +487,10 @@ func TestConvertFrom(t *testing.T) {
 	assert.Equal(t, checlusterv1.Spec.Database.PostgresEnv[0].Name, "database-name")
 	assert.Equal(t, checlusterv1.Spec.Database.PostgresEnv[0].Value, "database-value")
 
-	assert.Equal(t, checlusterv1.Spec.DevWorkspace.ControllerImage, "DevWorkspaceImage")
 	assert.Equal(t, checlusterv1.Spec.DevWorkspace.RunningLimit, "RunningLimit")
 	assert.Equal(t, checlusterv1.Spec.DevWorkspace.SecondsOfInactivityBeforeIdling, pointer.Int32Ptr(1800))
 	assert.Equal(t, checlusterv1.Spec.DevWorkspace.SecondsOfRunBeforeIdling, pointer.Int32Ptr(-1))
 	assert.True(t, checlusterv1.Spec.DevWorkspace.Enable)
-	assert.Equal(t, checlusterv1.Spec.DevWorkspace.Env[0].Name, "dev-workspace-name")
-	assert.Equal(t, checlusterv1.Spec.DevWorkspace.Env[0].Value, "dev-workspace-value")
 
 	assert.Equal(t, checlusterv1.Spec.Dashboard.Warning, "DashboardWarning")
 
@@ -526,7 +531,7 @@ func TestConvertFrom(t *testing.T) {
 	assert.Equal(t, checlusterv1.Spec.Server.ExternalPluginRegistry, true)
 	assert.Equal(t, checlusterv1.Spec.Server.GitSelfSignedCert, true)
 	assert.Equal(t, checlusterv1.Spec.Server.NonProxyHosts, "NonProxyHosts_1|NonProxyHosts_2")
-	assert.Equal(t, checlusterv1.Spec.Server.OpenVSXRegistryURL, "open-vsx-registry")
+	assert.Equal(t, *checlusterv1.Spec.Server.OpenVSXRegistryURL, "open-vsx-registry")
 	assert.Equal(t, checlusterv1.Spec.Server.PluginRegistryCpuLimit, "2")
 	assert.Equal(t, checlusterv1.Spec.Server.PluginRegistryCpuRequest, "1")
 	assert.Equal(t, checlusterv1.Spec.Server.PluginRegistryImage, "PluginRegistryImage")
@@ -545,6 +550,7 @@ func TestConvertFrom(t *testing.T) {
 	assert.Equal(t, checlusterv1.Spec.Server.SingleHostGatewayConfigSidecarImage, "ConfigSidecarImage")
 	assert.Equal(t, checlusterv1.Spec.Server.SingleHostGatewayImage, "GatewayImage")
 	assert.Equal(t, checlusterv1.Spec.Server.WorkspaceNamespaceDefault, "WorkspaceNamespaceName")
+	assert.Equal(t, checlusterv1.Spec.Server.AllowAutoProvisionUserNamespace, pointer.BoolPtr(true))
 	assert.Equal(t, checlusterv1.Spec.Server.WorkspaceDefaultEditor, "DefaultEditor")
 	assert.Equal(t, checlusterv1.Spec.Server.WorkspaceDefaultComponents, []devfile.Component{{Name: "universal-developer-image"}})
 	assert.Equal(t, checlusterv1.Spec.Server.WorkspacePodNodeSelector, map[string]string{"a": "b", "c": "d"})
@@ -564,6 +570,13 @@ func TestConvertFrom(t *testing.T) {
 	assert.Equal(t, checlusterv1.Spec.Storage.WorkspacePVCStorageClassName, "StorageClass")
 	assert.Equal(t, checlusterv1.Spec.Storage.PerWorkspaceStrategyPvcClaimSize, "PerWorkspaceStorageClaimSize")
 	assert.Equal(t, checlusterv1.Spec.Storage.PerWorkspaceStrategyPVCStorageClassName, "PerWorkspaceStorageClass")
+
+	assert.Equal(t, checlusterv1.Spec.GitServices.GitHub[0].SecretName, "github-secret-name")
+	assert.Equal(t, checlusterv1.Spec.GitServices.GitHub[0].Endpoint, "github-endpoint")
+	assert.Equal(t, checlusterv1.Spec.GitServices.GitLab[0].SecretName, "gitlab-secret-name")
+	assert.Equal(t, checlusterv1.Spec.GitServices.GitLab[0].Endpoint, "gitlab-endpoint")
+	assert.Equal(t, checlusterv1.Spec.GitServices.BitBucket[0].SecretName, "bitbucket-secret-name")
+	assert.Equal(t, checlusterv1.Spec.GitServices.BitBucket[0].Endpoint, "bitbucket-endpoint")
 }
 
 func TestShouldConvertFromWhenOnlyMemoryResourceSpecified(t *testing.T) {
