@@ -163,6 +163,7 @@ func TestConvertTo(t *testing.T) {
 				CheClusterRoles:                     "CheClusterRoles_1,CheClusterRoles_2",
 				CheWorkspaceClusterRole:             "CheWorkspaceClusterRole",
 				WorkspaceNamespaceDefault:           "WorkspaceNamespaceDefault",
+				AllowAutoProvisionUserNamespace:     pointer.BoolPtr(true),
 				WorkspaceDefaultEditor:              "WorkspaceDefaultEditor",
 				WorkspaceDefaultComponents: []devfile.Component{
 					{
@@ -251,7 +252,7 @@ func TestConvertTo(t *testing.T) {
 						Value: "dashboard-value",
 					},
 				},
-				OpenVSXRegistryURL: "open-vsx-registry",
+				OpenVSXRegistryURL: pointer.StringPtr("open-vsx-registry"),
 			},
 			Database: chev1.CheClusterSpecDB{
 				ExternalDb:              true,
@@ -333,21 +334,33 @@ func TestConvertTo(t *testing.T) {
 			},
 			DevWorkspace: chev1.CheClusterSpecDevWorkspace{
 				Enable:                          true,
-				ControllerImage:                 "ControllerImage",
 				RunningLimit:                    "RunningLimit",
 				SecondsOfInactivityBeforeIdling: pointer.Int32Ptr(1800),
 				SecondsOfRunBeforeIdling:        pointer.Int32Ptr(-1),
-				Env: []corev1.EnvVar{
-					{
-						Name:  "dev-workspace-name",
-						Value: "dev-workspace-value",
-					},
-				},
 			},
 			Dashboard: chev1.CheClusterSpecDashboard{
 				Warning: "DashboardWarning",
 			},
-		},
+			GitServices: chev1.CheClusterGitServices{
+				GitHub: []chev1.GitHubService{
+					{
+						SecretName: "github-secret-name",
+						Endpoint:   "github-endpoint",
+					},
+				},
+				GitLab: []chev1.GitLabService{
+					{
+						SecretName: "gitlab-secret-name",
+						Endpoint:   "gitlab-endpoint",
+					},
+				},
+				BitBucket: []chev1.BitBucketService{
+					{
+						SecretName: "bitbucket-secret-name",
+						Endpoint:   "bitbucket-endpoint",
+					},
+				},
+			}},
 		Status: chev1.CheClusterStatus{
 			CheClusterRunning:  "Available",
 			CheVersion:         "CheVersion",
@@ -414,6 +427,7 @@ func TestConvertTo(t *testing.T) {
 
 	assert.Equal(t, checlusterv2.Spec.DevEnvironments.TrustedCerts.GitTrustedCertsConfigMapName, "che-git-self-signed-cert")
 	assert.Equal(t, checlusterv2.Spec.DevEnvironments.DefaultNamespace.Template, "WorkspaceNamespaceDefault")
+	assert.Equal(t, checlusterv2.Spec.DevEnvironments.DefaultNamespace.AutoProvision, pointer.BoolPtr(true))
 	assert.Equal(t, checlusterv2.Spec.DevEnvironments.DefaultEditor, "WorkspaceDefaultEditor")
 	assert.Equal(t, checlusterv2.Spec.DevEnvironments.DefaultComponents, []devfile.Component{{Name: "universal-developer-image"}})
 	assert.Equal(t, checlusterv2.Spec.DevEnvironments.NodeSelector, map[string]string{"a": "b", "c": "d"})
@@ -459,9 +473,6 @@ func TestConvertTo(t *testing.T) {
 	assert.Equal(t, checlusterv2.Spec.Components.Database.Pvc.ClaimSize, "DatabasePvcClaimSize")
 	assert.Equal(t, checlusterv2.Spec.Components.Database.Pvc.StorageClass, "PostgresPVCStorageClassName")
 
-	assert.Equal(t, checlusterv2.Spec.Components.DevWorkspace.Deployment.Containers[0].Image, "ControllerImage")
-	assert.Equal(t, checlusterv2.Spec.Components.DevWorkspace.Deployment.Containers[0].Env[0].Name, "dev-workspace-name")
-	assert.Equal(t, checlusterv2.Spec.Components.DevWorkspace.Deployment.Containers[0].Env[0].Value, "dev-workspace-value")
 	assert.Equal(t, checlusterv2.Spec.Components.DevWorkspace.RunningLimit, "RunningLimit")
 
 	assert.Equal(t, checlusterv2.Spec.Components.ImagePuller.Enable, true)
@@ -495,7 +506,7 @@ func TestConvertTo(t *testing.T) {
 	assert.Equal(t, checlusterv2.Spec.Components.PluginRegistry.Deployment.Containers[0].Resources.Requests.Cpu, resource.MustParse("1"))
 	assert.Equal(t, checlusterv2.Spec.Components.PluginRegistry.Deployment.Containers[0].Resources.Requests.Memory, resource.MustParse("100Mi"))
 	assert.Equal(t, checlusterv2.Spec.Components.PluginRegistry.DisableInternalRegistry, true)
-	assert.Equal(t, checlusterv2.Spec.Components.PluginRegistry.OpenVSXURL, "open-vsx-registry")
+	assert.Equal(t, *checlusterv2.Spec.Components.PluginRegistry.OpenVSXURL, "open-vsx-registry")
 	assert.Equal(t, checlusterv2.Spec.Components.PluginRegistry.ExternalPluginRegistries, []chev2.ExternalPluginRegistry{{Url: "PluginRegistryUrl"}})
 
 	assert.Equal(t, checlusterv2.Spec.DevEnvironments.Storage.PerUserStrategyPvcConfig.ClaimSize, "WorkspacePvcClaimSize")
@@ -514,6 +525,13 @@ func TestConvertTo(t *testing.T) {
 	assert.Equal(t, checlusterv2.Status.PluginRegistryURL, "PluginRegistryURL")
 	assert.Equal(t, checlusterv2.Status.Reason, "Reason")
 	assert.Equal(t, checlusterv2.Status.PostgresVersion, "PostgresVersion")
+
+	assert.Equal(t, checlusterv2.Spec.GitServices.GitHub[0].SecretName, "github-secret-name")
+	assert.Equal(t, checlusterv2.Spec.GitServices.GitHub[0].Endpoint, "github-endpoint")
+	assert.Equal(t, checlusterv2.Spec.GitServices.GitLab[0].SecretName, "gitlab-secret-name")
+	assert.Equal(t, checlusterv2.Spec.GitServices.GitLab[0].Endpoint, "gitlab-endpoint")
+	assert.Equal(t, checlusterv2.Spec.GitServices.BitBucket[0].SecretName, "bitbucket-secret-name")
+	assert.Equal(t, checlusterv2.Spec.GitServices.BitBucket[0].Endpoint, "bitbucket-endpoint")
 }
 
 func TestShouldConvertToWhenOnlyMemoryResourceSpecified(t *testing.T) {
