@@ -61,6 +61,10 @@ func (src *CheCluster) ConvertTo(dstRaw conversion.Hub) error {
 		return err
 	}
 
+	if err := src.convertTo_GitServices(dst); err != nil {
+		return err
+	}
+
 	if err := src.convertTo_Status(dst); err != nil {
 		return err
 	}
@@ -68,6 +72,37 @@ func (src *CheCluster) ConvertTo(dstRaw conversion.Hub) error {
 	return nil
 }
 
+func (src *CheCluster) convertTo_GitServices(dst *chev2.CheCluster) error {
+	for _, github := range src.Spec.GitServices.GitHub {
+		dst.Spec.GitServices.GitHub = append(
+			dst.Spec.GitServices.GitHub,
+			chev2.GitHubService{
+				SecretName: github.SecretName,
+				Endpoint:   github.Endpoint,
+			})
+	}
+
+	for _, gitlab := range src.Spec.GitServices.GitLab {
+		dst.Spec.GitServices.GitLab = append(
+			dst.Spec.GitServices.GitLab,
+			chev2.GitLabService{
+				SecretName: gitlab.SecretName,
+				Endpoint:   gitlab.Endpoint,
+			})
+	}
+
+	for _, bitbucket := range src.Spec.GitServices.BitBucket {
+		dst.Spec.GitServices.BitBucket = append(
+			dst.Spec.GitServices.BitBucket,
+			chev2.BitBucketService{
+				SecretName: bitbucket.SecretName,
+				Endpoint:   bitbucket.Endpoint,
+			})
+	}
+
+	return nil
+}
+
 func (src *CheCluster) convertTo_Status(dst *chev2.CheCluster) error {
 	dst.Status.PostgresVersion = src.Spec.Database.PostgresVersion
 	dst.Status.CheURL = src.Status.CheURL
@@ -112,6 +147,7 @@ func (src *CheCluster) convertTo_DevEnvironments(dst *chev2.CheCluster) error {
 	}
 
 	dst.Spec.DevEnvironments.DefaultNamespace.Template = src.Spec.Server.WorkspaceNamespaceDefault
+	dst.Spec.DevEnvironments.DefaultNamespace.AutoProvision = src.Spec.Server.AllowAutoProvisionUserNamespace
 	dst.Spec.DevEnvironments.NodeSelector = utils.CloneMap(src.Spec.Server.WorkspacePodNodeSelector)
 
 	for _, v := range src.Spec.Server.WorkspacePodTolerations {
@@ -254,14 +290,6 @@ func (src *CheCluster) convertTo_Components(dst *chev2.CheCluster) error {
 }
 
 func (src *CheCluster) convertTo_Components_DevWorkspace(dst *chev2.CheCluster) error {
-	container := toCheV2ContainerWithImageAndEnv(
-		constants.DevWorkspaceController,
-		src.Spec.DevWorkspace.ControllerImage,
-		src.Spec.DevWorkspace.Env)
-	if container != nil {
-		dst.Spec.Components.DevWorkspace.Deployment = &chev2.Deployment{Containers: []chev2.Container{*container}}
-	}
-
 	dst.Spec.Components.DevWorkspace.RunningLimit = src.Spec.DevWorkspace.RunningLimit
 	return nil
 }
