@@ -63,11 +63,14 @@ type CheClusterSpec struct {
 	// +optional
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Kubernetes Image Puller"
 	ImagePuller CheClusterSpecImagePuller `json:"imagePuller"`
-
 	// DevWorkspace operator configuration
 	// +optional
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Dev Workspace operator"
 	DevWorkspace CheClusterSpecDevWorkspace `json:"devWorkspace"`
+	// A configuration that allows users to work with remote Git repositories.
+	// +optional
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Git Services"
+	GitServices CheClusterGitServices `json:"gitServices"`
 }
 
 // +k8s:openapi-gen=true
@@ -136,6 +139,10 @@ type CheClusterSpecServer struct {
 	// +optional
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,xDescriptors="urn:alm:descriptor:com.tectonic.ui:hidden"
 	AllowUserDefinedWorkspaceNamespaces bool `json:"allowUserDefinedWorkspaceNamespaces"`
+	// Indicates if is allowed to automatically create a user namespace.
+	// If it set to false, then user namespace must be pre-created by a cluster administrator.
+	// +optional
+	AllowAutoProvisionUserNamespace *bool `json:"allowAutoProvisionUserNamespace,omitempty"`
 	// Deprecated. The value of this flag is ignored.
 	// The Che Operator will automatically detect whether the router certificate is self-signed and propagate it to other components, such as the Che server.
 	// +optional
@@ -361,10 +368,12 @@ type CheClusterSpecServer struct {
 	// The plugin ID must have `publisher/plugin/version`.
 	// The URI must start from `http`.
 	// +optional
+	// +kubebuilder:default:=che-incubator/che-code/insiders
 	WorkspaceDefaultEditor string `json:"workspaceDefaultEditor,omitempty"`
 	// Default components applied to DevWorkspaces.
 	// These default components are meant to be used when a Devfile does not contain any components.
 	// +optional
+	// +kubebuilder:default:={{name: universal-developer-image, container: {image: "quay.io/devfile/universal-developer-image:ubi8-38da5c2"}}}
 	WorkspaceDefaultComponents []devfile.Component `json:"workspaceDefaultComponents,omitempty"`
 	// List of environment variables to set in the Che server container.
 	// +optional
@@ -380,7 +389,7 @@ type CheClusterSpecServer struct {
 	DashboardEnv []corev1.EnvVar `json:"dashboardEnv,omitempty"`
 	// Open VSX registry URL. If omitted an embedded instance will be used.
 	// +optional
-	OpenVSXRegistryURL string `json:"openVSXRegistryURL,omitempty"`
+	OpenVSXRegistryURL *string `json:"openVSXRegistryURL,omitempty"`
 }
 
 // +k8s:openapi-gen=true
@@ -783,6 +792,67 @@ type ExternalDevfileRegistries struct {
 	Url string `json:"url,omitempty"`
 }
 
+type CheClusterGitServices struct {
+	// Enables users to work with repositories hosted on GitHub (github.com or GitHub Enterprise).
+	// +optional
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="GitHub"
+	GitHub []GitHubService `json:"github,omitempty"`
+	// Enables users to work with repositories hosted on GitLab (gitlab.com or self-hosted).
+	// +optional
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="GitLab"
+	GitLab []GitLabService `json:"gitlab,omitempty"`
+	// Enables users to work with repositories hosted on Bitbucket (bitbucket.org or self-hosted).
+	// +optional
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Bitbucket"
+	BitBucket []BitBucketService `json:"bitbucket,omitempty"`
+}
+
+// GitHubService enables users to work with repositories hosted on GitHub (GitHub.com or GitHub Enterprise).
+type GitHubService struct {
+	// Kubernetes secret, that contains Base64-encoded GitHub OAuth Client id and GitHub OAuth Client secret,
+	// that stored in `id` and `secret` keys respectively.
+	// See the following page: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-2-for-github/.
+	// +kubebuilder:validation:Required
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,xDescriptors="urn:alm:descriptor:io.kubernetes:Secret"
+	SecretName string `json:"secretName"`
+	// GitHub server endpoint URL.
+	// +kubebuilder:validation:Required
+	// +kubebuilder:default:="https://github.com"
+	Endpoint string `json:"endpoint"`
+}
+
+// GitLabService enables users to work with repositories hosted on GitLab (gitlab.com or self-hosted).
+type GitLabService struct {
+	// Kubernetes secret, that contains Base64-encoded GitHub Application id and GitLab Application Client secret,
+	// that stored in `id` and `secret` keys respectively.
+	// See the following page: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-2-for-gitlab/.
+	// +kubebuilder:validation:Required
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,xDescriptors="urn:alm:descriptor:io.kubernetes:Secret"
+	SecretName string `json:"secretName"`
+	// GitLab server endpoint URL.
+	// +kubebuilder:validation:Required
+	// +kubebuilder:default:="https://gitlab.com"
+	Endpoint string `json:"endpoint"`
+}
+
+// BitBucketService enables users to work with repositories hosted on Bitbucket (bitbucket.org or self-hosted).
+type BitBucketService struct {
+	// Kubernetes secret, that contains Base64-encoded Bitbucket OAuth 1.0 or OAuth 2.0 data.
+	// For OAuth 1.0: private key, Bitbucket Application link consumer key and Bitbucket Application link shared secret must be stored
+	// in `private.key`, `consumer.key` and `shared_secret` keys respectively.
+	// See the following page: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-1-for-a-bitbucket-server/.
+	// For OAuth 2.0: Bitbucket OAuth consumer key and Bitbucket OAuth consumer secret must be stored
+	// in `id` and `secret` keys respectively.
+	// See the following page: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-2-for-the-bitbucket-cloud/.
+	// +kubebuilder:validation:Required
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,xDescriptors="urn:alm:descriptor:io.kubernetes:Secret"
+	SecretName string `json:"secretName"`
+	// Bitbucket server endpoint URL.
+	// +kubebuilder:validation:Required
+	// +kubebuilder:default:="https://bitbucket.org"
+	Endpoint string `json:"endpoint,omitempty"`
+}
+
 // GatewayPhase describes the different phases of the Che gateway lifecycle
 type GatewayPhase string
 
