@@ -12,6 +12,11 @@
 
 package constants
 
+import (
+	corev1 "k8s.io/api/core/v1"
+	"k8s.io/utils/pointer"
+)
+
 const (
 	// PostgresSQL
 	DefaultPostgresUser              = "pgche"
@@ -138,4 +143,14 @@ var (
 		"app":       "che",
 		"component": "che-gateway-config",
 	}
+
+	DefaultWorkspaceContainerSecurityContext = corev1.SecurityContext{
+		Capabilities: &corev1.Capabilities{
+			Add: []corev1.Capability{
+				"SETGID",
+				"SETUID",
+			},
+		},
+		AllowPrivilegeEscalation: pointer.BoolPtr(true),
+	}
 )
