@@ -41,6 +41,11 @@ func (p *PluginRegistryReconciler) getPluginRegistryDeploymentSpec(ctx *chetypes
 		},
 	}
 
+	if ctx.CheCluster.IsOpenVSXURLEmpty() {
+		resources.Requests[corev1.ResourceMemory] = resource.MustParse(constants.DefaultPluginRegistryMemoryRequestEmbeddedOpenVSXRegistry)
+		resources.Limits[corev1.ResourceMemory] = resource.MustParse(constants.DefaultPluginRegistryMemoryLimitEmbeddedOpenVSXRegistry)
+	}
+
 	deployment := registry.GetSpecRegistryDeployment(
 		ctx,
 		registryType,
@@ -50,6 +55,11 @@ func (p *PluginRegistryReconciler) getPluginRegistryDeploymentSpec(ctx *chetypes
 		resources,
 		probePath)
 
+	if ctx.CheCluster.IsOpenVSXURLEmpty() {
+		// Add time to start embedded VSX registry
+		deployment.Spec.Template.Spec.Containers[0].LivenessProbe.InitialDelaySeconds = 300
+	}
+
 	deploy.EnsurePodSecurityStandards(deployment, constants.DefaultSecurityContextRunAsUser, constants.DefaultSecurityContextFsGroup)
 	deploy.CustomizeDeployment(deployment, ctx.CheCluster.Spec.Components.PluginRegistry.Deployment)
 	return deployment
